package Data::Processor;

use strict;
use 5.008_005;
our $VERSION = '0.0.1';

1;
__END__

=encoding utf-8

=head1 NAME

Data::Processor - Transform Perl Data Structures, Verify against a Schema, Produce Data from a Schema

=head1 SYNOPSIS

  use Data::Processor;

=head1 DESCRIPTION

Data::Processor is a tool for transforming, verifying, and producing Perl data structures from / against a schema, defined as a Perl data structure.

=head1 AUTHOR

Matthias Bloch E<lt>matthias.bloch@puffin.chE<gt>

=head1 COPYRIGHT

Copyright 2015- Matthias Bloch

=head1 LICENSE

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 SEE ALSO

=cut
